package com.jz.manage.moduls.controller.finance;

import com.jz.common.bean.BasePageBean;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.utils.Result;
import com.jz.manage.moduls.controller.BaseController;
import com.jz.manage.moduls.controller.finance.platForm.OrderCountInfoDto;
import com.jz.manage.moduls.controller.finance.platForm.PlatFormMoneyAndDepartDto;
import com.jz.manage.moduls.controller.finance.platForm.TradeDetilDto;
import com.jz.manage.moduls.controller.finance.platForm.TradeDetilRequest;
import com.jz.manage.moduls.service.PlatformTradeFlowInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 平台交易流水(TPlatformTradeFlowInfo)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:44
 */
@RestController
@RequestMapping("platformTradeFlowInfo")
@Api(tags = "平台--利润中心")
public class PlatformTradeFlowInfoController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private PlatformTradeFlowInfoService platformTradeFlowInfoService;

    /**
     * 获取平台累计收入和企业总数
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/platFormMoneyAndDepart")
    @ApiOperation(value = "财务管理---累计收入和企业总数", notes = "累计收入和企业总数")
    public Result<PlatFormMoneyAndDepartDto> getPlatFormMoneyAndDepart(HttpServletRequest requset) throws Exception {
        Result<PlatFormMoneyAndDepartDto> result = new Result<>();

        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());

        PlatFormMoneyAndDepartDto dto = platformTradeFlowInfoService.queryPlatFormMoneyAndDepart(map);
        result.setData(dto);
        return result;
    }

    /**
     * 财务管理---我的订单
     *
     * @return
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/orderCountList")
    @ApiOperation(value = "财务管理---我的订单", notes = "我的订单")
    public PageInfoResponse<OrderCountInfoDto> findList(BasePageBean pageBean, HttpServletRequest httpRequest) throws Exception  {
        PageInfoResponse<OrderCountInfoDto> pageInfo = new PageInfoResponse<OrderCountInfoDto>();
        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());
        try {
            pageInfo = platformTradeFlowInfoService.findListOrderCount(pageBean,httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }

        return pageInfo;
    }

    /**
     * 财务管理--交易明细
     *
     * @return
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/tradeDetilList")
    @ApiOperation(value = "财务管理--交易明细", notes = "交易明细")
    public PageInfoResponse<TradeDetilDto> getFinanceTradeDetil(TradeDetilRequest tradeDetilRequest, HttpServletRequest httpRequest) throws Exception  {
        PageInfoResponse<TradeDetilDto> pageInfo = new PageInfoResponse<TradeDetilDto>();
        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());
        try {
            pageInfo = platformTradeFlowInfoService.findListFinanceTradeDetil(tradeDetilRequest,httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }
        return pageInfo;
    }

}